deleteContent abstract method

Future<void> deleteContent(
  1. String name
)

Removes the object with name name from the persistence system. It can also unmount the persistence system if it is no longer useful.

Implementation

Future<void> deleteContent(final String name);