JsonNamedFileRepository<T> class
abstract
Repository per memorizzare su una cache basata su file di testo lo stato (compatto e completo indifferentemente) di un device.
- Implemented types
- Mixed-in types
Constructors
Properties
Methods
-
content(
String name) → Future< T?> -
Reads the content of the whole object stored inside the persistence system with name
name. Returnsnullif it cannot read the object.override -
createDirectory(
String path, String newFolder) → Future< void> -
Creates a folder named
newFolderinside the path specified bypath.inherited -
createDirectorySync(
String path, String newFolder) → void -
SYNCHRONOUS VERSION
inherited
-
deleteContent(
String name) → Future< void> -
Removes the object with name
namefrom the persistence system. It can also unmount the persistence system if it is no longer useful.override -
deleteFile(
String fileFolder, String fileName) → Future< void> -
Deletes a file.
inherited
-
deleteFileSync(
String fileFolder, String fileName) → void -
SYNCHRONOUS VERSION
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readFromFile(
String fileFolder, String fileName, {bool byteMode = false}) → Future -
Reads from a file and returns the content on the form of a
StringorUint8List.inherited -
readFromFileSync(
String fileFolder, String fileName, {bool byteMode = false}) → dynamic -
Reads from a file and returns the content on the form of a
StringorUint8List.inherited -
saveContent(
String name, T content) → Future< void> -
Stores the object
contentof typeTinside the predefined (by the implementer) persistent system, storing it with namename.override -
saveToFile(
String fileFolder, String fileName, dynamic fileContent, {bool append = false, bool byteMode = false}) → Future< void> -
Saves on a file (which path is
fileFolder/fileName) the content infileContent.inherited -
saveToFileSync(
String fileFolder, String fileName, dynamic fileContent, {bool append = false, bool byteMode = false}) → void -
SYNCHRONOUS VERSION
inherited
-
setFileFolder(
[String fileFolder = ""]) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited